@@ -1,11 +1,11 @@
 /* This is a proposed C API for support of SASL
  *
- *********************************IMPORTANT******************************
- * send email to chris.newman@innosoft.com and sasl-bugs@andrew.cmu.edu *
- * if you need to add new error codes, callback types, property values, *
- * etc.   It is important to keep the multiple implementations of this  *
- * API from diverging.                                                  *
- *********************************IMPORTANT******************************
+ *********************************IMPORTANT*******************************
+ * send email to chris.newman@innosoft.com and cyrus-bugs@andrew.cmu.edu *
+ * if you need to add new error codes, callback types, property values,  *
+ * etc.   It is important to keep the multiple implementations of this   *
+ * API from diverging.                                                   *
+ *********************************IMPORTANT*******************************
  *
  * Basic Type Summary:
  *  sasl_conn_t       Context for a SASL connection negotiation
@@ -121,7 +121,7 @@
 
 #define SASL_VERSION_MAJOR 2
 #define SASL_VERSION_MINOR 1
-#define SASL_VERSION_STEP 12
+#define SASL_VERSION_STEP 14
 
 #include "prop.h"
 
@@ -230,6 +230,9 @@ typedef struct sasl_secret {
  */
 typedef struct sasl_rand_s sasl_rand_t;
 
+#ifdef __cplusplus
+extern "C" {
+#endif
 
 /****************************
  * Configure Basic Services *
@@ -1179,4 +1182,8 @@ LIBSASL_API int sasl_decode(sasl_conn_t *conn,
 			    const char *input, unsigned inputlen,
 			    const char **output, unsigned *outputlen);
 
+#ifdef __cplusplus
+}
+#endif
+
 #endif /* SASL_H */
