@@ -130,14 +130,14 @@ int cache_init(void) {
 	memset(base, 0, bytes);
 
 	memcpy(base, cache_magic, 64);
-	table_stats = base + 64;
+	table_stats = (void *)((char *)base + 64);
 	table_stats->table_size = table_size;
 	table_stats->max_buckets_per = CACHE_MAX_BUCKETS_PER;
 	table_stats->sizeof_bucket = sizeof(struct bucket);
 	table_stats->timeout = table_timeout;
 	table_stats->bytes = bytes;
 
-	(char *)table = (char *)table_stats + 128;
+	table = (void *)((char *)table_stats + 128);
 
 	/**************************************************************
 	 * Last, initialize the hash table locking.
@@ -441,8 +441,6 @@ unsigned int cache_get_next_prime(unsigned int number) {
 	unsigned int	max;
 	unsigned int	mom;
 	unsigned int	alloc;
-	unsigned int	count;
-
 
 	max = number + 20000;
 
@@ -644,8 +642,7 @@ int cache_get_wlock(unsigned int slot) {
 			logger(L_DEBUG, L_FUNC, "attempting a write lock on slot: %d", slot);
 
 		rc = fcntl(lock.flock_fd, F_SETLKW, &lock_st);
-
-	} while (errno == EINTR);
+	} while (rc != 0 && errno == EINTR);
 
 	if (rc != 0) {	
 		rc = errno;
@@ -682,8 +679,7 @@ int cache_get_rlock(unsigned int slot) {
 			logger(L_DEBUG, L_FUNC, "attempting a read lock on slot: %d", slot);
 
 		rc = fcntl(lock.flock_fd, F_SETLKW, &lock_st);
-
-	} while (errno == EINTR);
+	} while (rc != 0 && errno == EINTR);
 
 	if (rc != 0) {	
 		rc = errno;
@@ -717,9 +713,8 @@ int cache_un_lock(unsigned int slot) {
 		if (flags & VERBOSE)
 			logger(L_DEBUG, L_FUNC, "attempting to release lock on slot: %d", slot);
 
-		rc = fcntl(lock.flock_fd, F_SETLK, &lock_st);
-
-	} while (errno == EINTR);
+		rc = fcntl(lock.flock_fd, F_SETLKW, &lock_st);
+	} while (rc != 0 && errno == EINTR);
 
 	if (rc != 0) {	
 		rc = errno;
