@@ -52,7 +52,7 @@
  *   nul delimited strings.
  * - Augmented the protocol to accept the service name and user realm.
  * 
- * Feb 2004: Partial rewrite and cleanup  by Jeremy Rumpf jrumpf@heavyload.net
+ * Feb 2003: Partial rewrite and cleanup  by Jeremy Rumpf jrumpf@heavyload.net
  * - Merge the doors and unix IPC methods under a common framework.
  *
  *   OVERVIEW
@@ -149,6 +149,7 @@ int main(int argc, char **argv) {
 	int 		rc;
 	int 		x;
 	struct flock	lockinfo;
+	char            *auth_mech_name = NULL;
 
 	SET_AUTH_PARAMETERS(argc, argv);
 
@@ -166,9 +167,17 @@ int main(int argc, char **argv) {
 		switch(option) {
 			case 'a':
 			        /* Only one at a time, please! */
-			        if(auth_mech) show_usage();
-				
-				set_auth_mech(optarg);
+			        if(auth_mech_name) {
+				    show_usage();
+				    break;
+				}
+
+				auth_mech_name = strdup(optarg);
+				if (!auth_mech_name) {
+				    logger(L_ERR, L_FUNC,
+					   "could not allocate memory");
+				    exit(1);
+				}
 				break;
 
 			case 'c':
@@ -182,7 +191,8 @@ int main(int argc, char **argv) {
 
 			case 'h':
 				show_usage();
-
+				break;
+				
 			case 'O':
 				set_mech_option(optarg);
 				break;
@@ -213,20 +223,25 @@ int main(int argc, char **argv) {
 
 			case 'v':
 				show_version();
-
+				break;
+				
 			default:
 				show_usage();
+				break;
 		}
 	}
 
 	if (run_path == NULL)
     		run_path = PATH_SASLAUTHD_RUNDIR;
 
-    	if (auth_mech == NULL) {
+    	if (auth_mech_name == NULL) {
 		logger(L_ERR, L_FUNC, "no authentication mechanism specified");
+		show_usage();
 		exit(1);
 	}
 
+	set_auth_mech(auth_mech_name);
+
 	if (flags & VERBOSE)  {
 		logger(L_DEBUG, L_FUNC, "num_procs  : %d", num_procs);
 
@@ -311,7 +326,7 @@ int main(int argc, char **argv) {
 	/*********************************************************
 	 * Enable general cleanup.
 	 **********************************************************/
-	atexit((void *)server_exit);
+	atexit(server_exit);
 
 	/*********************************************************
 	 * If required, enable the process model.
@@ -376,8 +391,9 @@ char *do_auth(const char *login, const char *password, const char *service, cons
 	}
 
 	if (strncmp(response, "NO", 2) == 0) {
-		logger(L_INFO, L_FUNC, "auth failure: [user=%s] [service=%s] [realm=%s] [mech=%s]", \
-			login, service, realm, auth_mech->name);
+		logger(L_INFO, L_FUNC, "auth failure: [user=%s] [service=%s] [realm=%s] [mech=%s] [reason=%s]", \
+			login, service, realm, auth_mech->name,
+		        strlen(response) >= 4 ? response+3 : "Unknown");
 
 		return response;
 	}
@@ -485,7 +501,7 @@ void signal_setup() {
 	/**************************************************************
 	 * Handler for SIGCHLD
 	 **************************************************************/
-	act_sigchld.sa_handler = (void *)handle_sigchld;
+	act_sigchld.sa_handler = handle_sigchld;
 	sigemptyset(&act_sigchld.sa_mask);
 
 	if (sigaction(SIGCHLD, &act_sigchld, NULL) != 0) {
@@ -537,7 +553,7 @@ void signal_setup() {
 	/**************************************************************
 	 * Handler for SIGTERM
 	 **************************************************************/
-	act_sigterm.sa_handler = (void *)server_exit;
+	act_sigterm.sa_handler = server_exit;
 	sigemptyset(&act_sigterm.sa_mask);
 
 	if (sigaction(SIGTERM, &act_sigterm, NULL) != 0) {
@@ -550,7 +566,7 @@ void signal_setup() {
 	/**************************************************************
 	 * Handler for SIGINT
 	 **************************************************************/
-	act_sigint.sa_handler = (void *)server_exit;
+	act_sigint.sa_handler = server_exit;
 	sigemptyset(&act_sigint.sa_mask);
 
 	if (sigaction(SIGINT, &act_sigint, NULL) != 0) {
@@ -665,7 +681,7 @@ void detach_tty() {
 	 * From this point on, stop printing errors out to stderr.
 	 **********************************************************/
 	flags &= ~LOG_USE_STDERR;
-	
+
 	close(STDIN_FILENO);
 	close(STDOUT_FILENO);
 	close(STDERR_FILENO);
@@ -673,10 +689,10 @@ void detach_tty() {
 	dup2(null_fd, STDIN_FILENO);
 	dup2(null_fd, STDOUT_FILENO);
 	dup2(null_fd, STDERR_FILENO);
-	
+
 	if (null_fd > 2)
 	    close(null_fd);
-	
+		
 	/*********************************************************
 	 * Locks don't persist across forks. Relock the pid file
 	 * to keep folks from having duplicate copies running...
@@ -934,12 +950,12 @@ void show_usage() {
     fprintf(stderr, "                 mechanism.\n");
     fprintf(stderr, "  -l             Disable accept() locking. Increases performance, but\n");
     fprintf(stderr, "                 may not be compatible with some operating systems.\n");
-    fprintf(stderr, "  -m <path>      Alternate path for the sslauthd working directory,\n");
+    fprintf(stderr, "  -m <path>      Alternate path for the saslauthd working directory,\n");
     fprintf(stderr, "                 must be absolute.\n"); 
     fprintf(stderr, "  -n <procs>     Number of worker processes to create.\n");
     fprintf(stderr, "  -s <kilobytes> Size of the credential cache (in kilobytes)\n");
     fprintf(stderr, "  -t <seconds>   Timeout for items in the credential cache (in seconds)\n");
-    fprintf(stderr, "  -v             Display version information and available\n");
+    fprintf(stderr, "  -v             Display version information and available mechs\n");
     fprintf(stderr, "  -V             Enable verbose logging\n");
     fprintf(stderr, "                 authentication mechanisms and exit.\n");
     fprintf(stderr, "  -h             Dispaly this message.\n\n");
